import React from 'react';
import { useWidgetContext } from '../../../context';
import { ChartType, useStatisticsData } from '../StatisticsUtils';
import { StatisticsBarWrapper } from '../presenters/StatisticsBarWrapper';
import { getMinusDays, getMinusMonths } from '../dateUtils';
import { createDaysArr, createMonthsArr, createYearsArr, getMonthsRate, getWeeksRate, getYearsRate, mapDaysRateForCharts, mapMonthsRateForCharts, mapYearsRateForCharts, parseResultForChart, } from '../StatisticsUtils';
export var StatisticsBarController = function (_a) {
    var _b;
    var setView = _a.setView;
    var _c = useWidgetContext(), client = _c.client, title = _c.config.title;
    var dateNow = Date.now();
    var dateNowDateFormat = new Date(dateNow);
    var monthNumber = 48 - (dateNowDateFormat.getUTCMonth() + 1);
    var requestParamsForWeek = {
        from: getMinusDays(dateNow, 7),
        limit: 7,
    };
    var requestParamsForMonths = {
        from: getMinusMonths(dateNow, monthNumber),
        limit: monthNumber,
    };
    var weekRateRareData = useStatisticsData(client, 'AutomationRate.Daily', requestParamsForWeek)[0];
    var monthsRateRareData = useStatisticsData(client, 'AutomationRate.Monthly', requestParamsForMonths)[0];
    var daysArr = createDaysArr(7);
    var monthsArr = createMonthsArr(12);
    var yearsArr = createYearsArr(4);
    var weekRate = getWeeksRate(weekRateRareData, daysArr);
    var monthsRate = getMonthsRate(monthsRateRareData, monthsArr);
    var yearsRate = getYearsRate(monthsRateRareData, yearsArr);
    var weekRateData = parseResultForChart(weekRate, mapDaysRateForCharts);
    var monthsRateData = parseResultForChart(monthsRate, mapMonthsRateForCharts);
    var yearsRateData = parseResultForChart(yearsRate, mapYearsRateForCharts);
    var rateData = (_b = {},
        _b[ChartType.weekly] = weekRateData,
        _b[ChartType.monthly] = monthsRateData,
        _b[ChartType.annual] = yearsRateData,
        _b);
    return (React.createElement(React.Fragment, null,
        React.createElement(StatisticsBarWrapper, { title: title, setView: setView, rateData: rateData })));
};
